/* fieldlvrowdata.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2003-2004 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: fieldlvrowdata.h,v 1.2 2004/03/18 07:00:49 ralf Exp $ */

#ifndef FIELDLVROWDATA_H
#define FIELDLVROWDATA_H

#include "aguixdefs.h"

class FieldLVRowData
{
public:
  FieldLVRowData();
  virtual ~FieldLVRowData();
  FieldLVRowData( const FieldLVRowData &other );
  FieldLVRowData &operator=( const FieldLVRowData &other );

  virtual FieldLVRowData *duplicate() const;
private:
};

#endif
